@@ -17,11 +17,12 @@ try:
 except ImportError:
     # dulwich >= 0.20
     from dulwich.objects import EmptyFileException
+
 import dulwich.repo
 
+from swh.loader.core.loader import DVCSLoader
 from swh.model import hashutil
 from swh.model.model import Origin, Snapshot, SnapshotBranch, TargetType
-from swh.loader.core.loader import DVCSLoader
 from swh.storage.algos.origin import origin_get_latest_visit_status
 
 from . import converters, utils
@@ -32,12 +33,10 @@ class GitLoaderFromDisk(DVCSLoader):
 
     """
 
-    CONFIG_BASE_FILENAME = "loader/git-disk"
-
     visit_type = "git"
 
-    def __init__(self, url, visit_date=None, directory=None, config=None):
-        super().__init__(logging_class="swh.loader.git.Loader", config=config)
+    def __init__(self, url, visit_date=None, directory=None):
+        super().__init__(logging_class="swh.loader.git.Loader")
         self.origin_url = url
         self.visit_date = visit_date
         self.directory = directory
@@ -388,9 +387,10 @@ class GitLoaderFromArchive(GitLoaderFromDisk):
 
 
 if __name__ == "__main__":
-    import click
     import logging
 
+    import click
+
     logging.basicConfig(
         level=logging.DEBUG, format="%(asctime)s %(process)d %(message)s"
     )
